@@ -17,7 +17,7 @@ from imaplib import IMAP4_SSL
 from base64 import b64encode
 from typing import List, Dict, Any
 from datetime import datetime
-from .utils import validate_template, validate_image, validate_path, validate_sender, validate_protocol_config, validate_account
+from .utils import validate_template, validate_image, validate_path, validate_sender, validate_protocol_config, validate_account, validate_date
 
 
 class EzSender:
@@ -518,11 +518,14 @@ class EzReader:
         if body:
             criteria += f' BODY "{body}"'
         if date:
-            criteria += f' ON {date}'
+            validate_date(date)
+            criteria += f' ON {date.strftime("%d-%b-%Y")}'
         if since:
-            criteria += f' SINCE {since}'
+            validate_date(since)
+            criteria += f' SINCE {since.strftime("%d-%b-%Y")}'
         if before:
-            criteria += f' BEFORE {before}'
+            validate_date(before)
+            criteria += f' BEFORE {before.strftime("%d-%b-%Y")}'
         criteria += ")"
 
         try:
